==> deepin-ocr_1.1.2.tar.xz: BUILD/translations/deepin-ocr_ta.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ta" version="2.1">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <location filename="../src/mainwidget.cpp" line="314"/>
        <source>Recognizing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.12.tar.xz: BUILD/translations/deepin-ocr_ta.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ta">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation>எந்த பார்க்கப்பட்ட தொடர்பு கொண்ட பொருளும் இல்லை</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation>தொடர்பு கொண்ட பொருளை பிரித்தெடுக்கவும்</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation>TXT ஆக மாற்றவும்</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <source>Recognizing</source>
        <translation>உறுதிப்படுத்தல்</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation>பிரித்தெடுக்கப்பட்டது</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation>OCR கரு</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation>கொடு</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation>க்கொடு</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation>அனைத்தையும் தேர்ந்தெடுக்கவும்</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation>செல்லவும்</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>முக்கியத்துவமுள்ள குறிப்பு: படத்தின் தெளிவு அதிகரித்தால், பொருள் அதிகமாக உறுதிப்படுத்தப்படும்</translation>
    </message>
</context>
</TS>
